@@ -69,8 +69,11 @@ class Mumble(threading.Thread):
         self.tokens = tokens
         self.__opus_profile = PYMUMBLE_AUDIO_TYPE_OPUS_PROFILE
         self.stereo = stereo
-
-        print(f"==== STEREO {stereo} ====")
+        
+        if stereo:
+            self.Log.debug("Working in STEREO mode.")
+        else:
+            self.Log.debug("Working in MONO mode.")
 
         self.receive_sound = False  # set to True to treat incoming audio, otherwise it is simply ignored
 
